// Radiator water damage monitoring (c)Peter Klingbeil 2021
// Every 60 seconds it is checked whether the sensor reports water.
// The alarm occurs after the delay at the latest.
// In the event of an alarm, a permanent acoustic signal sounds.
// It can only be switched off by disconnecting the supply voltage.

#include "pitches.h"      // Tone library
#include "Narcoleptic.h"  // A sleep library for Arduino (C) 2010 Peter Knight (Cathedrow)

#ifndef cbi
#define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
#endif
#ifndef sbi
#define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
#endif
 
// notes for an alarm tone
int alarm[] = {NOTE_C5, NOTE_C6};

int duration = 300;  // 300 miliseconds tone duration
int sensorValue;

void setup() 
{ 
  // initalize serial communicaton - test
  Serial.begin(9600);
  pinMode(A1, OUTPUT);  // alive LED
}
 
void loop() 
{
 
  sensorValue = analogRead(A3); // Get sensor value
  // print out the value
  Serial.println(sensorValue);
  
  // delay in between reads for stability & show the LED if the System is alive

while (sensorValue < 1000)  // Water! 
{  
  for (int thisNote = 0; thisNote < 2; thisNote++) 
  {
    // pin8 output the voice, every scale is 0.1 sencond
    tone(8, alarm[thisNote], duration);    
    // Output the voice after several minutes
    delay(100);
  }  
 }

  digitalWrite(A1, HIGH);   // turn the alive LED on 
  delay(100);               // wait (Puls)
  digitalWrite(A1, LOW);    // turn the alive LED off

  // Set the CPU in sleep mode to reduce the power consumption from 25 mA to 10 mA
  cbi(ADCSRA,ADEN);         // disable A/C-Converter
  pinMode(A1,INPUT);        // set all used port to intput to save power 
  Narcoleptic.delay(60000); // power down for 60 seconds
  pinMode(A1,OUTPUT);       // set all ports into state before sleep
  sbi(ADCSRA,ADEN);         // enable A/C-Converter

}
